Package 'micturate'

Title: Tools for urine samples
Description: Simple tools for helping with various aspects of urinary analysis.
Authors: Tom Wilson [aut, cre]
Maintainer: Tom Wilson <[email protected]>
License: GPL (>= 3)
Version: 0.1.2
Built: 2026-06-06 21:10:22 UTC
Source: https://github.com/wilsontom/micturate

Help Index


Correction Factor

Description

Calculate the normalisation correction factor

Usage

correction_factor(x, norm_value = 1.006)

Arguments

x

a numeric vector of refractive index values

norm_value

a numeric value specifying the target value to normalise to

Value

a numeric vector of correction factors


96 Well Plate Map for Total Creatinine Assay

Description

96 Well Plate Map for Total Creatinine Assay

Usage

creatinine_plate_index

Format

A tbl_df

WELL

well position

NAME

sample name

CLASS

sample class

CONC

concentration


Normalisation Volumes

Description

Calculate the required volumes based on normalisation correction factors

Usage

normalisation_volumes(x, total_volume = 500)

Arguments

x

a numeric vector of correction factors

total_volume

a numeric value specifying the total required volume (urine + water)

Value

a tbl_df of required urine and water volumes


Urine Pooling Sheet

Description

Urine Pooling Sheet

Usage

pooling_sheet(ri_data, norm_value, volume)

Arguments

ri_data

a tbl_df of sample_name, value and group

norm_value

a numeric value to normalise to

volume

a numeric value for the total volume per sample

Value

a tbl_df of pooling volumes for each sample_name


Predict RI values from HPLC-RI

Description

Predict RI values from HPLC-RI

Usage

refractive_index_prediction(gaml_file, standards)

Arguments

gaml_file

a GAML file containing HPLC-RI data.

standards

a two column tbl_df of external calibration standards. Columns must be named sample_name and specific_gravity. sample_name should use the format S01, S02, S03, etc... If NULL then a set of package calibration standards will be used instead.

Value

a tbl_df of predicted refractive index values


Urine Sample Adjustments

Description

Urine Sample Adjustments

Usage

sampel_adjustments(ri_data, norm_value, volume)

Arguments

ri_data

a tbl_df of sample_name, value

norm_value

a numeric value to normalise to

volume

a numeric value for the total volume per sample

Value

a tbl_df of pooling volumes for each sample_name


96 Well Plate Map for Total Urea Assay

Description

96 Well Plate Map for Total Urea Assay

Usage

urea_plate_index

Format

A tbl_df

WELL

well position

NAME

sample name

CLASS

sample class

CONC

concentration