| Title: | Tools for urine samples |
|---|---|
| Description: | Simple tools for helping with various aspects of urinary analysis. |
| Authors: | Tom Wilson [aut, cre] |
| Maintainer: | Tom Wilson <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.1.2 |
| Built: | 2026-06-06 21:10:22 UTC |
| Source: | https://github.com/wilsontom/micturate |
Calculate the normalisation correction factor
correction_factor(x, norm_value = 1.006)correction_factor(x, norm_value = 1.006)
x |
a numeric vector of refractive index values |
norm_value |
a numeric value specifying the target value to normalise to |
a numeric vector of correction factors
96 Well Plate Map for Total Creatinine Assay
creatinine_plate_indexcreatinine_plate_index
A tbl_df
well position
sample name
sample class
concentration
Calculate the required volumes based on normalisation correction factors
normalisation_volumes(x, total_volume = 500)normalisation_volumes(x, total_volume = 500)
x |
a numeric vector of correction factors |
total_volume |
a numeric value specifying the total required volume (urine + water) |
a tbl_df of required urine and water volumes
Urine Pooling Sheet
pooling_sheet(ri_data, norm_value, volume)pooling_sheet(ri_data, norm_value, volume)
ri_data |
a |
norm_value |
a numeric value to normalise to |
volume |
a numeric value for the total volume per sample |
a tbl_df of pooling volumes for each sample_name
Predict RI values from HPLC-RI
refractive_index_prediction(gaml_file, standards)refractive_index_prediction(gaml_file, standards)
gaml_file |
a GAML file containing HPLC-RI data. |
standards |
a two column |
a tbl_df of predicted refractive index values
Urine Sample Adjustments
sampel_adjustments(ri_data, norm_value, volume)sampel_adjustments(ri_data, norm_value, volume)
ri_data |
a |
norm_value |
a numeric value to normalise to |
volume |
a numeric value for the total volume per sample |
a tbl_df of pooling volumes for each sample_name
96 Well Plate Map for Total Urea Assay
urea_plate_indexurea_plate_index
A tbl_df
well position
sample name
sample class
concentration